
from flask import Flask, json, Response
from hdd_stat.stat import get_labels, get_full_stat

app = Flask('hdd_stat')

@app.route('/')
def index():
    data = get_full_stat(get_labels())
    resp = Response(json.dumps([r._asdict() for r in data]))
    resp.headers['Access-Control-Allow-Origin'] = '*'
    return resp

# dev server
if __name__ == '__main__':
    app.run(host = '', port = 5000, debug = True)



from setuptools import setup, find_packages

setup(
    name = "hdd-stat",
    description = "",
    version = "1.1.0",
    author = 'Lajos Santa',
    author_email = 'santa.lajos@coldline.hu',
    url = 'https://github.com/voidpp/hdd-stat',
    install_requires = [
        "prettytable==0.7.2",
        "psutil==4.1.0",
        "Flask==0.10.1",
    ],
    scripts = [
        "bin/hdd-stat"
    ],
    packages = find_packages(),
)




import psutil
import subprocess
import os
import re
from collections import namedtuple

partition = namedtuple('partition', ['device', 'label', 'mount', 'used', 'total', 'free', 'percent'])

def get_labels():
    prog = re.compile('(\/dev\/[a-z0-9]{3,}) on .+ \[(.+)\]')
    mounts = subprocess.check_output(['mount','-l']).decode('utf8')
    disks = {}
    for line in mounts.split('\n'):
        res = prog.match(line)
        if res is None:
            continue
        disks[res.group(1)] = res.group(2)
    return disks

def get_full_stat(labels):
    partitions = psutil.disk_partitions()

    data = []

    for part in partitions:
        if part.device not in labels:
            continue

        usage = psutil.disk_usage(part.mountpoint)

        data.append(partition(
            part.device,
            labels[part.device],
            part.mountpoint,
            usage.used,
            usage.total,
            usage.free,
            usage.percent,
        ))

    return data
